@@ -22,10 +22,10 @@
 #include <QSaveFile>
 #include <QStandardPaths>
 #include <QTemporaryDir>
-#include <kfilterdev.h>
+#include <kcompressiondevice.h>
 
 #ifndef Q_OS_WIN
-#include <errno.h>
+#include <cerrno>
 #include <unistd.h> // symlink
 #endif
 
@@ -348,7 +348,7 @@ void KArchiveTest::setupData()
     QTest::addColumn<QString>("mimeType");
 
     QTest::newRow(".tar.gz") << "karchivetest.tar.gz"
-                             << "application/x-gzip";
+                             << "application/gzip";
 #if HAVE_BZIP2_SUPPORT
     QTest::newRow(".tar.bz2") << "karchivetest.tar.bz2"
                               << "application/x-bzip";
@@ -359,6 +359,10 @@ void KArchiveTest::setupData()
     QTest::newRow(".tar.xz") << "karchivetest.tar.xz"
                              << "application/x-xz";
 #endif
+#if HAVE_ZSTD_SUPPORT
+    QTest::newRow(".tar.zst") << "karchivetest.tar.zst"
+                              << "application/zstd";
+#endif
 }
 
 /**
@@ -564,7 +568,7 @@ void KArchiveTest::testUncompress()
 
     // testCreateTar must have been run first.
     QVERIFY(QFile::exists(fileName));
-    KFilterDev filterDev(fileName);
+    KCompressionDevice filterDev(fileName);
     QByteArray buffer;
     buffer.resize(8 * 1024);
     // qDebug() << "buffer.size()=" << buffer.size();
